AnsiColor

Enum AnsiColor 

pub enum AnsiColor {
Show 16 variants Black = 0, Red = 1, Green = 2, Yellow = 3, Blue = 4, Magenta = 5, Cyan = 6, White = 7, BrightBlack = 8, BrightRed = 9, BrightGreen = 10, BrightYellow = 11, BrightBlue = 12, BrightMagenta = 13, BrightCyan = 14, BrightWhite = 15,
}
Standard 16-color ANSI palette.

Prefer Ansi colors when you want your game to respect the user’s terminal color theme (e.g., Solarized, Nord, or custom themes). Use Rgb for fixed colors that must appear identical regardless of the user’s terminal configuration.

Variants



Black = 0

Black.



Red = 1

Red.



Green = 2

Green.



Yellow = 3

Yellow.



Blue = 4

Blue.



Magenta = 5

Magenta.



Cyan = 6

Cyan.



White = 7

White.



BrightBlack = 8

Bright Black.



BrightRed = 9

Bright Red.



BrightGreen = 10

Bright Green.



BrightYellow = 11

Bright Yellow.



BrightBlue = 12

Bright Blue.



BrightMagenta = 13

Bright Magenta.



BrightCyan = 14

Bright Cyan.



BrightWhite = 15

Bright White.

Implementations

Source

impl AnsiColor

pub const fn to_index(self) -> u8

Returns the ANSI color code as a u8 index.