Color

Enum Color 

pub enum Color {
    Default,
    Ansi(AnsiColor),
    Indexed(u8),
    Rgb {
        r: u8,
        g: u8,
        b: u8,
    },
}
Represents a color in the terminal grid.

Variants



Default

Backend’s default foreground/background color.

This tells the rendering backend to use the terminal’s configured default colors (e.g., the user’s background color preference).



Ansi(AnsiColor)

One of the 16 standard ANSI colors.

Use these to respect the user’s terminal theme.



Indexed(u8)

256-color palette index.



Rgb

24-bit RGB color.

Use this for exact color matching regardless of terminal settings.

Fields

r: u8

Red channel.

g: u8

Green channel.

b: u8

Blue channel.

Implementations

Source

impl Color

pub const BLACK: Self

Standard Black (ANSI).

pub const RED: Self

Standard Red (ANSI).

pub const GREEN: Self

Standard Green (ANSI).

pub const YELLOW: Self

Standard Yellow (ANSI).

pub const BLUE: Self

Standard Blue (ANSI).

pub const MAGENTA: Self

Standard Magenta (ANSI).

pub const CYAN: Self

Standard Cyan (ANSI).

pub const WHITE: Self

Standard White (ANSI).

pub const BRIGHT_BLACK: Self

Bright Black / dark grey (ANSI).

pub const BRIGHT_RED: Self

Bright Red (ANSI).

pub const BRIGHT_GREEN: Self

Bright Green (ANSI).

pub const BRIGHT_YELLOW: Self

Bright Yellow (ANSI).

pub const BRIGHT_BLUE: Self

Bright Blue (ANSI).

pub const BRIGHT_MAGENTA: Self

Bright Magenta (ANSI).

pub const BRIGHT_CYAN: Self

Bright Cyan (ANSI).

pub const BRIGHT_WHITE: Self

Bright White (ANSI).